# Varenv Release Note
* version **1.0.6**
* date **17/12/2021**

## Enhancement
* Better code quality, pep8 applied.
* __CONF_FILE variable being attributed in a wrong *~and silly~* way corrected.
* Do not fail when file is not found, only warn.

## Features
* Accepting YAML as config file.
* variables now can have alias.
